/* wptContext.h - Internal file to store private contexts
 *	Copyright (C) 2001-2005 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
#ifndef WPT_CONTEXT_H
#define WPT_CONTEXT_H

/* Window subclassing context. */
struct subclass_s {
    HWND    dlg;
    WNDPROC old;	/* old window procedure */
    WNDPROC current;	/* the subclass window procedure */
    void * opaque;
};

/* Container for a gpgme key. */
struct winpt_key_s {
    const char  *uid;		    /* pointer to the first uid */
    const char  *keyid;		    /* pointer to the first keyid */
    unsigned int key_pair:1;	    /* is a complete key. */
    unsigned int is_protected:1;    /* secret key is protected. */
    unsigned int update:1;	    /* 1=need to reload key. */
    unsigned int is_v3:1;	    /* key is version 3 (RSA/MD5) */
    unsigned int has_photo:1;	    /* 1=contains photo-id. */
    unsigned int flags;
    gpgme_key_t  ctx;		    /* if not NULL, the actualy gpgme key */
    struct keycache_s *ext;	    /* extended key attributes or NULL. */
    /* Callback structure if a listview needs to be updated. */
    struct {
	listview_ctrl_t ctl;	    /* the listview control. */
	int idx;		    /* selected index. */
	int new_val;		    /* new value */
    } callback;
    char tmp_keyid[8+1];
};
typedef struct winpt_key_s * winpt_key_t;

/* Text input context for detached sigs. */
struct text_input_s {
    char  *data;    /* input data. */
    size_t length;  /* length of input data. */
    int    type;    /* type of data (0=text data for signature) */
};

/* Date context for the date selection dialog. */
struct date_s {
    int         cancel;	    /* cancel was hit. */
    const char *text;	    /* text used as the title. */
    SYSTEMTIME  st;	    /* selected time by the user. */
};

struct md_file_s {
    int             mdalgo;
    listview_ctrl_t lv;
};

struct secdel_confirm_s {
    unsigned int       yes:1;	/* if yes=1 user confirmed delete. */
    listview_ctrl_t    lv_files;/* listview control with the files to delete. */
};


/* Progress filter context. */
struct progress_filter_s {
    HWND     hwnd;
    HWND     dlg;
    HANDLE   thread_hd;
    int	     error;
    const char *what;
    int	     type;
    unsigned curr;
    unsigned total;
};

/* URL context. */
struct URL_ctx_s {
    const char *title;	    /* title for the dialog. */
    const char *desc;	    /* description of what to do. */
    char url[256];	    /* the selected URL. */
    char proxy[64];
    int  port;		    /* the port to use. */
    int  cancel;	    /* user cancelled operation. */
    int  check;		    /* use strict URL checking. */
};

/* Key generation context */
struct genkey_s {
    gpgme_key_t  newkey;	/* handle to the new key */
    int		 interactive;
    unsigned int first_start:1;
    unsigned int cancel:1;
    char	 *fpr;		/* fingerprint of the key. */
};

#endif /* WPT_CONTEXT_H */
