/* wptUTF8.cpp - UTF8 conversation
 *	Copyright (C) 2002, 2004, 2005, 2006 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <windows.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>

#include "wptTypes.h"
#include "wptErrors.h"


char*
native_to_utf8 (const char *string)
{
    wchar_t *result;
    char *native;
    int n;

    n = MultiByteToWideChar (GetACP (), 0, string, -1, NULL, 0);
    if (n < 0)
	return NULL;

    result = (wchar_t*)malloc ((n+1) * sizeof *result);
    if (!result)
	BUG (0);

    n = MultiByteToWideChar (GetACP (), 0, string, -1, result, n);
    if (n < 0) {
	free (result);
	return NULL;
    }

    n = WideCharToMultiByte (CP_UTF8, 0, result, -1, NULL, 0, NULL, NULL);
    if (n < 0)
	return NULL;

    native = (char*)malloc (n+1);
    if (!native)
	BUG (0);

    n = WideCharToMultiByte (CP_UTF8, 0, result, -1, native, n, NULL, NULL);
    if (n < 0) {
	free (result);
	return NULL;
    }

    free (result);
    return native;
}


/* Convert utf8 string @str to native CP. */
char*
utf8_to_native (const char *string)
{
    wchar_t *result;
    char *native;    
    int n;

    n = MultiByteToWideChar (CP_UTF8, 0, string, -1, NULL, 0);
    if (n < 0)
	return NULL;

    result = (wchar_t*)malloc ((n+1) * sizeof *result);
    if (!result)
	BUG (0);

    n = MultiByteToWideChar (CP_UTF8, 0, string, -1, result, n);
    if (n < 0) {
	free (result);
	return NULL;
    }

    n = WideCharToMultiByte (GetACP (), 0, result, -1, NULL, 0, NULL, NULL);
    if (n < 0)
	return NULL;

    native = (char*)malloc (n+1);
    if (!native)
	BUG (0);

    n = WideCharToMultiByte (GetACP (), 0, result, -1, native, n, NULL, NULL);
    if (n < 0) {
	free (result);
	return NULL;
    }

    free (result);
    return native;
}


/* Return -1 if the string contains any 8-bit characters. */
int
is_8bit_string (const char *str)
{
    size_t i;

    for (i = 0; i < strlen (str); i++) {
	if (str[i] & 0x80)
	    return -1;
    }
    return 0;
}
